# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'BlockDeviceConstraintArgs',
    'BlockDeviceLinkArgs',
    'BlockDeviceSnapshotArgs',
    'BlockDeviceSnapshotLinkArgs',
    'BlockDeviceTagArgs',
    'SnapshotLinkArgs',
    'GetBlockDeviceTagArgs',
]

@pulumi.input_type
class BlockDeviceConstraintArgs:
    def __init__(__self__, *,
                 expression: pulumi.Input[str],
                 mandatory: pulumi.Input[bool]):
        pulumi.set(__self__, "expression", expression)
        pulumi.set(__self__, "mandatory", mandatory)

    @property
    @pulumi.getter
    def expression(self) -> pulumi.Input[str]:
        return pulumi.get(self, "expression")

    @expression.setter
    def expression(self, value: pulumi.Input[str]):
        pulumi.set(self, "expression", value)

    @property
    @pulumi.getter
    def mandatory(self) -> pulumi.Input[bool]:
        return pulumi.get(self, "mandatory")

    @mandatory.setter
    def mandatory(self, value: pulumi.Input[bool]):
        pulumi.set(self, "mandatory", value)


@pulumi.input_type
class BlockDeviceLinkArgs:
    def __init__(__self__, *,
                 rel: pulumi.Input[str],
                 href: Optional[pulumi.Input[str]] = None,
                 hrefs: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None):
        pulumi.set(__self__, "rel", rel)
        if href is not None:
            pulumi.set(__self__, "href", href)
        if hrefs is not None:
            pulumi.set(__self__, "hrefs", hrefs)

    @property
    @pulumi.getter
    def rel(self) -> pulumi.Input[str]:
        return pulumi.get(self, "rel")

    @rel.setter
    def rel(self, value: pulumi.Input[str]):
        pulumi.set(self, "rel", value)

    @property
    @pulumi.getter
    def href(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "href")

    @href.setter
    def href(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "href", value)

    @property
    @pulumi.getter
    def hrefs(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        return pulumi.get(self, "hrefs")

    @hrefs.setter
    def hrefs(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "hrefs", value)


@pulumi.input_type
class BlockDeviceSnapshotArgs:
    def __init__(__self__, *,
                 created_at: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 id: Optional[pulumi.Input[str]] = None,
                 is_current: Optional[pulumi.Input[bool]] = None,
                 links: Optional[pulumi.Input[Sequence[pulumi.Input['BlockDeviceSnapshotLinkArgs']]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 org_id: Optional[pulumi.Input[str]] = None,
                 owner: Optional[pulumi.Input[str]] = None,
                 updated_at: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] created_at: Date when entity was created. Date and time format is ISO 8601 and UTC.
        :param pulumi.Input[str] description: Describes machine within the scope of your organization and is not propagated to the cloud.
        :param pulumi.Input[str] id: ID of the block device snapshot.
        :param pulumi.Input[bool] is_current: Indicates whether snapshot on block device is current.
        :param pulumi.Input[Sequence[pulumi.Input['BlockDeviceSnapshotLinkArgs']]] links: HATEOAS of the entity
        :param pulumi.Input[str] name: Human-friendly name used as an identifier in APIs that support this option.
        :param pulumi.Input[str] org_id: ID of organization that block device snapshot belongs to.
        :param pulumi.Input[str] owner: Email of block device snapshot owner.
        :param pulumi.Input[str] updated_at: Date when entity was last updated. Date and time format is ISO 8601 and UTC.
        """
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if id is not None:
            pulumi.set(__self__, "id", id)
        if is_current is not None:
            pulumi.set(__self__, "is_current", is_current)
        if links is not None:
            pulumi.set(__self__, "links", links)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if owner is not None:
            pulumi.set(__self__, "owner", owner)
        if updated_at is not None:
            pulumi.set(__self__, "updated_at", updated_at)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[str]]:
        """
        Date when entity was created. Date and time format is ISO 8601 and UTC.
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "created_at", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Describes machine within the scope of your organization and is not propagated to the cloud.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def id(self) -> Optional[pulumi.Input[str]]:
        """
        ID of the block device snapshot.
        """
        return pulumi.get(self, "id")

    @id.setter
    def id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "id", value)

    @property
    @pulumi.getter(name="isCurrent")
    def is_current(self) -> Optional[pulumi.Input[bool]]:
        """
        Indicates whether snapshot on block device is current.
        """
        return pulumi.get(self, "is_current")

    @is_current.setter
    def is_current(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "is_current", value)

    @property
    @pulumi.getter
    def links(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['BlockDeviceSnapshotLinkArgs']]]]:
        """
        HATEOAS of the entity
        """
        return pulumi.get(self, "links")

    @links.setter
    def links(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['BlockDeviceSnapshotLinkArgs']]]]):
        pulumi.set(self, "links", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Human-friendly name used as an identifier in APIs that support this option.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[str]]:
        """
        ID of organization that block device snapshot belongs to.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "org_id", value)

    @property
    @pulumi.getter
    def owner(self) -> Optional[pulumi.Input[str]]:
        """
        Email of block device snapshot owner.
        """
        return pulumi.get(self, "owner")

    @owner.setter
    def owner(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "owner", value)

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> Optional[pulumi.Input[str]]:
        """
        Date when entity was last updated. Date and time format is ISO 8601 and UTC.
        """
        return pulumi.get(self, "updated_at")

    @updated_at.setter
    def updated_at(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "updated_at", value)


@pulumi.input_type
class BlockDeviceSnapshotLinkArgs:
    def __init__(__self__, *,
                 rel: pulumi.Input[str],
                 href: Optional[pulumi.Input[str]] = None,
                 hrefs: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None):
        pulumi.set(__self__, "rel", rel)
        if href is not None:
            pulumi.set(__self__, "href", href)
        if hrefs is not None:
            pulumi.set(__self__, "hrefs", hrefs)

    @property
    @pulumi.getter
    def rel(self) -> pulumi.Input[str]:
        return pulumi.get(self, "rel")

    @rel.setter
    def rel(self, value: pulumi.Input[str]):
        pulumi.set(self, "rel", value)

    @property
    @pulumi.getter
    def href(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "href")

    @href.setter
    def href(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "href", value)

    @property
    @pulumi.getter
    def hrefs(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        return pulumi.get(self, "hrefs")

    @hrefs.setter
    def hrefs(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "hrefs", value)


@pulumi.input_type
class BlockDeviceTagArgs:
    def __init__(__self__, *,
                 key: pulumi.Input[str],
                 value: pulumi.Input[str]):
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> pulumi.Input[str]:
        return pulumi.get(self, "key")

    @key.setter
    def key(self, value: pulumi.Input[str]):
        pulumi.set(self, "key", value)

    @property
    @pulumi.getter
    def value(self) -> pulumi.Input[str]:
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: pulumi.Input[str]):
        pulumi.set(self, "value", value)


@pulumi.input_type
class SnapshotLinkArgs:
    def __init__(__self__, *,
                 rel: pulumi.Input[str],
                 href: Optional[pulumi.Input[str]] = None,
                 hrefs: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None):
        pulumi.set(__self__, "rel", rel)
        if href is not None:
            pulumi.set(__self__, "href", href)
        if hrefs is not None:
            pulumi.set(__self__, "hrefs", hrefs)

    @property
    @pulumi.getter
    def rel(self) -> pulumi.Input[str]:
        return pulumi.get(self, "rel")

    @rel.setter
    def rel(self, value: pulumi.Input[str]):
        pulumi.set(self, "rel", value)

    @property
    @pulumi.getter
    def href(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "href")

    @href.setter
    def href(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "href", value)

    @property
    @pulumi.getter
    def hrefs(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        return pulumi.get(self, "hrefs")

    @hrefs.setter
    def hrefs(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "hrefs", value)


@pulumi.input_type
class GetBlockDeviceTagArgs:
    def __init__(__self__, *,
                 key: str,
                 value: str):
        """
        :param str key: Tag’s key.
        :param str value: Tag’s value.
        """
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> str:
        """
        Tag’s key.
        """
        return pulumi.get(self, "key")

    @key.setter
    def key(self, value: str):
        pulumi.set(self, "key", value)

    @property
    @pulumi.getter
    def value(self) -> str:
        """
        Tag’s value.
        """
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: str):
        pulumi.set(self, "value", value)





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'GetEnumerationGcpResult',
    'AwaitableGetEnumerationGcpResult',
    'get_enumeration_gcp',
    'get_enumeration_gcp_output',
]

@pulumi.output_type
class GetEnumerationGcpResult:
    """
    A collection of values returned by getEnumerationGcp.
    """
    def __init__(__self__, client_email=None, id=None, private_key=None, private_key_id=None, project_id=None, regions=None):
        if client_email and not isinstance(client_email, str):
            raise TypeError("Expected argument 'client_email' to be a str")
        pulumi.set(__self__, "client_email", client_email)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if private_key and not isinstance(private_key, str):
            raise TypeError("Expected argument 'private_key' to be a str")
        pulumi.set(__self__, "private_key", private_key)
        if private_key_id and not isinstance(private_key_id, str):
            raise TypeError("Expected argument 'private_key_id' to be a str")
        pulumi.set(__self__, "private_key_id", private_key_id)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)
        if regions and not isinstance(regions, list):
            raise TypeError("Expected argument 'regions' to be a list")
        pulumi.set(__self__, "regions", regions)

    @property
    @pulumi.getter(name="clientEmail")
    def client_email(self) -> str:
        return pulumi.get(self, "client_email")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="privateKey")
    def private_key(self) -> str:
        return pulumi.get(self, "private_key")

    @property
    @pulumi.getter(name="privateKeyId")
    def private_key_id(self) -> str:
        return pulumi.get(self, "private_key_id")

    @property
    @pulumi.getter(name="projectId")
    def project_id(self) -> str:
        return pulumi.get(self, "project_id")

    @property
    @pulumi.getter
    def regions(self) -> Sequence[str]:
        """
        A set of Region names to enable provisioning on. Example: northamerica-northeast1
        """
        return pulumi.get(self, "regions")


class AwaitableGetEnumerationGcpResult(GetEnumerationGcpResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetEnumerationGcpResult(
            client_email=self.client_email,
            id=self.id,
            private_key=self.private_key,
            private_key_id=self.private_key_id,
            project_id=self.project_id,
            regions=self.regions)


def get_enumeration_gcp(client_email: Optional[str] = None,
                        private_key: Optional[str] = None,
                        private_key_id: Optional[str] = None,
                        project_id: Optional[str] = None,
                        opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetEnumerationGcpResult:
    """
    ## Example Usage
    ### S

    This is an example of how to lookup a region enumeration data source for GCP cloud account.

    **Region enumeration data source for GCP**
    ```python
    import pulumi
    import pulumi_vra as vra

    this = vra.region.get_enumeration_gcp(client_email=var["client_email"],
        private_key_id=var["private_key_id"],
        private_key=var["private_key"],
        project_id=var["project_id"])
    ```

    The region enumeration data source for GCP cloud account supports the following arguments:


    :param str client_email: Client E-mail ID.
    :param str private_key: GCP Private key.
    :param str private_key_id: GCP Private key ID.
    :param str project_id: GCP Project ID.
    """
    __args__ = dict()
    __args__['clientEmail'] = client_email
    __args__['privateKey'] = private_key
    __args__['privateKeyId'] = private_key_id
    __args__['projectId'] = project_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('vra:region/getEnumerationGcp:getEnumerationGcp', __args__, opts=opts, typ=GetEnumerationGcpResult).value

    return AwaitableGetEnumerationGcpResult(
        client_email=__ret__.client_email,
        id=__ret__.id,
        private_key=__ret__.private_key,
        private_key_id=__ret__.private_key_id,
        project_id=__ret__.project_id,
        regions=__ret__.regions)


@_utilities.lift_output_func(get_enumeration_gcp)
def get_enumeration_gcp_output(client_email: Optional[pulumi.Input[str]] = None,
                               private_key: Optional[pulumi.Input[str]] = None,
                               private_key_id: Optional[pulumi.Input[str]] = None,
                               project_id: Optional[pulumi.Input[str]] = None,
                               opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetEnumerationGcpResult]:
    """
    ## Example Usage
    ### S

    This is an example of how to lookup a region enumeration data source for GCP cloud account.

    **Region enumeration data source for GCP**
    ```python
    import pulumi
    import pulumi_vra as vra

    this = vra.region.get_enumeration_gcp(client_email=var["client_email"],
        private_key_id=var["private_key_id"],
        private_key=var["private_key"],
        project_id=var["project_id"])
    ```

    The region enumeration data source for GCP cloud account supports the following arguments:


    :param str client_email: Client E-mail ID.
    :param str private_key: GCP Private key.
    :param str private_key_id: GCP Private key ID.
    :param str project_id: GCP Project ID.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'GetEnumerationAzureResult',
    'AwaitableGetEnumerationAzureResult',
    'get_enumeration_azure',
    'get_enumeration_azure_output',
]

@pulumi.output_type
class GetEnumerationAzureResult:
    """
    A collection of values returned by getEnumerationAzure.
    """
    def __init__(__self__, application_id=None, application_key=None, id=None, regions=None, subscription_id=None, tenant_id=None):
        if application_id and not isinstance(application_id, str):
            raise TypeError("Expected argument 'application_id' to be a str")
        pulumi.set(__self__, "application_id", application_id)
        if application_key and not isinstance(application_key, str):
            raise TypeError("Expected argument 'application_key' to be a str")
        pulumi.set(__self__, "application_key", application_key)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if regions and not isinstance(regions, list):
            raise TypeError("Expected argument 'regions' to be a list")
        pulumi.set(__self__, "regions", regions)
        if subscription_id and not isinstance(subscription_id, str):
            raise TypeError("Expected argument 'subscription_id' to be a str")
        pulumi.set(__self__, "subscription_id", subscription_id)
        if tenant_id and not isinstance(tenant_id, str):
            raise TypeError("Expected argument 'tenant_id' to be a str")
        pulumi.set(__self__, "tenant_id", tenant_id)

    @property
    @pulumi.getter(name="applicationId")
    def application_id(self) -> str:
        return pulumi.get(self, "application_id")

    @property
    @pulumi.getter(name="applicationKey")
    def application_key(self) -> str:
        return pulumi.get(self, "application_key")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def regions(self) -> Sequence[str]:
        """
        A set of Region names to enable provisioning on. Example: northamerica-northeast1
        """
        return pulumi.get(self, "regions")

    @property
    @pulumi.getter(name="subscriptionId")
    def subscription_id(self) -> str:
        return pulumi.get(self, "subscription_id")

    @property
    @pulumi.getter(name="tenantId")
    def tenant_id(self) -> str:
        return pulumi.get(self, "tenant_id")


class AwaitableGetEnumerationAzureResult(GetEnumerationAzureResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetEnumerationAzureResult(
            application_id=self.application_id,
            application_key=self.application_key,
            id=self.id,
            regions=self.regions,
            subscription_id=self.subscription_id,
            tenant_id=self.tenant_id)


def get_enumeration_azure(application_id: Optional[str] = None,
                          application_key: Optional[str] = None,
                          subscription_id: Optional[str] = None,
                          tenant_id: Optional[str] = None,
                          opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetEnumerationAzureResult:
    """
    ## Example Usage
    ### S

    This is an example of how to lookup a region enumeration data source for Azure cloud account.

    **Region enumeration data source for Azure**
    ```python
    import pulumi
    import pulumi_vra as vra

    this = vra.region.get_enumeration_azure(application_id=var["application_id"],
        application_key=var["application_key"],
        subscription_id=var["subscription_id"],
        tenant_id=var["tenant_id"])
    ```

    The region enumeration data source for Azure cloud account supports the following arguments:


    :param str application_id: Azure Client Application ID
    :param str application_key: Azure Client Application Secret Key
    :param str subscription_id: Azure Subscription ID
    :param str tenant_id: Azure Tenant ID
    """
    __args__ = dict()
    __args__['applicationId'] = application_id
    __args__['applicationKey'] = application_key
    __args__['subscriptionId'] = subscription_id
    __args__['tenantId'] = tenant_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('vra:region/getEnumerationAzure:getEnumerationAzure', __args__, opts=opts, typ=GetEnumerationAzureResult).value

    return AwaitableGetEnumerationAzureResult(
        application_id=__ret__.application_id,
        application_key=__ret__.application_key,
        id=__ret__.id,
        regions=__ret__.regions,
        subscription_id=__ret__.subscription_id,
        tenant_id=__ret__.tenant_id)


@_utilities.lift_output_func(get_enumeration_azure)
def get_enumeration_azure_output(application_id: Optional[pulumi.Input[str]] = None,
                                 application_key: Optional[pulumi.Input[str]] = None,
                                 subscription_id: Optional[pulumi.Input[str]] = None,
                                 tenant_id: Optional[pulumi.Input[str]] = None,
                                 opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetEnumerationAzureResult]:
    """
    ## Example Usage
    ### S

    This is an example of how to lookup a region enumeration data source for Azure cloud account.

    **Region enumeration data source for Azure**
    ```python
    import pulumi
    import pulumi_vra as vra

    this = vra.region.get_enumeration_azure(application_id=var["application_id"],
        application_key=var["application_key"],
        subscription_id=var["subscription_id"],
        tenant_id=var["tenant_id"])
    ```

    The region enumeration data source for Azure cloud account supports the following arguments:


    :param str application_id: Azure Client Application ID
    :param str application_key: Azure Client Application Secret Key
    :param str subscription_id: Azure Subscription ID
    :param str tenant_id: Azure Tenant ID
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'GetRegionResult',
    'AwaitableGetRegionResult',
    'get_region',
    'get_region_output',
]

@pulumi.output_type
class GetRegionResult:
    """
    A collection of values returned by getRegion.
    """
    def __init__(__self__, cloud_account_id=None, created_at=None, external_region_id=None, filter=None, id=None, name=None, org_id=None, owner=None, region=None, updated_at=None):
        if cloud_account_id and not isinstance(cloud_account_id, str):
            raise TypeError("Expected argument 'cloud_account_id' to be a str")
        pulumi.set(__self__, "cloud_account_id", cloud_account_id)
        if created_at and not isinstance(created_at, str):
            raise TypeError("Expected argument 'created_at' to be a str")
        pulumi.set(__self__, "created_at", created_at)
        if external_region_id and not isinstance(external_region_id, str):
            raise TypeError("Expected argument 'external_region_id' to be a str")
        pulumi.set(__self__, "external_region_id", external_region_id)
        if filter and not isinstance(filter, str):
            raise TypeError("Expected argument 'filter' to be a str")
        pulumi.set(__self__, "filter", filter)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if org_id and not isinstance(org_id, str):
            raise TypeError("Expected argument 'org_id' to be a str")
        pulumi.set(__self__, "org_id", org_id)
        if owner and not isinstance(owner, str):
            raise TypeError("Expected argument 'owner' to be a str")
        pulumi.set(__self__, "owner", owner)
        if region and not isinstance(region, str):
            raise TypeError("Expected argument 'region' to be a str")
        pulumi.set(__self__, "region", region)
        if updated_at and not isinstance(updated_at, str):
            raise TypeError("Expected argument 'updated_at' to be a str")
        pulumi.set(__self__, "updated_at", updated_at)

    @property
    @pulumi.getter(name="cloudAccountId")
    def cloud_account_id(self) -> str:
        return pulumi.get(self, "cloud_account_id")

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> str:
        """
        Date when the entity was created. The date is in ISO 8601 and UTC.
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter(name="externalRegionId")
    def external_region_id(self) -> str:
        """
        Unique identifier of region on the provider side.
        """
        return pulumi.get(self, "external_region_id")

    @property
    @pulumi.getter
    def filter(self) -> Optional[str]:
        return pulumi.get(self, "filter")

    @property
    @pulumi.getter
    def id(self) -> str:
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        Name of region on the provider side. In vSphere, the name of the region is different from its id.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="orgId")
    def org_id(self) -> str:
        """
        The id of the organization this entity belongs to.
        """
        return pulumi.get(self, "org_id")

    @property
    @pulumi.getter
    def owner(self) -> str:
        """
        Email of the user that owns the entity.
        """
        return pulumi.get(self, "owner")

    @property
    @pulumi.getter
    def region(self) -> Optional[str]:
        return pulumi.get(self, "region")

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> str:
        """
        Date when the entity was last updated. The date is ISO 8601 and UTC.
        """
        return pulumi.get(self, "updated_at")


class AwaitableGetRegionResult(GetRegionResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetRegionResult(
            cloud_account_id=self.cloud_account_id,
            created_at=self.created_at,
            external_region_id=self.external_region_id,
            filter=self.filter,
            id=self.id,
            name=self.name,
            org_id=self.org_id,
            owner=self.owner,
            region=self.region,
            updated_at=self.updated_at)


def get_region(cloud_account_id: Optional[str] = None,
               filter: Optional[str] = None,
               id: Optional[str] = None,
               region: Optional[str] = None,
               opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetRegionResult:
    """
    This is an example of how to lookup a region data source:

    **Region data source by id:**

    ```python
    import pulumi
    import pulumi_vra as vra

    this = vra.region.get_region(id=var["vra_region_id"])
    ```

    **Region data source by filter:**

    ```python
    import pulumi
    import pulumi_vra as vra

    this = vra.region.get_region(filter=f"name eq '{var['vra_region_name']}'")
    ```

    **Region data source by cloud account id and region:**

    ```python
    import pulumi
    import pulumi_vra as vra

    this = vra.region.get_region(cloud_account_id=var["vra_cloud_account_id"],
        region=var["vra_region_external_id"])
    ```


    :param str cloud_account_id: The id of the cloud account the region belongs to.
    :param str filter: Search criteria to narrow down Regions.
    :param str id: The id of the region instance.
    :param str region: The specific region associated with the cloud account. On vSphere, this is the external ID.
    """
    __args__ = dict()
    __args__['cloudAccountId'] = cloud_account_id
    __args__['filter'] = filter
    __args__['id'] = id
    __args__['region'] = region
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('vra:region/getRegion:getRegion', __args__, opts=opts, typ=GetRegionResult).value

    return AwaitableGetRegionResult(
        cloud_account_id=__ret__.cloud_account_id,
        created_at=__ret__.created_at,
        external_region_id=__ret__.external_region_id,
        filter=__ret__.filter,
        id=__ret__.id,
        name=__ret__.name,
        org_id=__ret__.org_id,
        owner=__ret__.owner,
        region=__ret__.region,
        updated_at=__ret__.updated_at)


@_utilities.lift_output_func(get_region)
def get_region_output(cloud_account_id: Optional[pulumi.Input[Optional[str]]] = None,
                      filter: Optional[pulumi.Input[Optional[str]]] = None,
                      id: Optional[pulumi.Input[Optional[str]]] = None,
                      region: Optional[pulumi.Input[Optional[str]]] = None,
                      opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetRegionResult]:
    """
    This is an example of how to lookup a region data source:

    **Region data source by id:**

    ```python
    import pulumi
    import pulumi_vra as vra

    this = vra.region.get_region(id=var["vra_region_id"])
    ```

    **Region data source by filter:**

    ```python
    import pulumi
    import pulumi_vra as vra

    this = vra.region.get_region(filter=f"name eq '{var['vra_region_name']}'")
    ```

    **Region data source by cloud account id and region:**

    ```python
    import pulumi
    import pulumi_vra as vra

    this = vra.region.get_region(cloud_account_id=var["vra_cloud_account_id"],
        region=var["vra_region_external_id"])
    ```


    :param str cloud_account_id: The id of the cloud account the region belongs to.
    :param str filter: Search criteria to narrow down Regions.
    :param str id: The id of the region instance.
    :param str region: The specific region associated with the cloud account. On vSphere, this is the external ID.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'ProfileImageMapping',
    'ProfileImageMappingConstraint',
    'GetProfileImageMappingResult',
    'GetProfileImageMappingConstraintResult',
]

@pulumi.output_type
class ProfileImageMapping(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "cloudConfig":
            suggest = "cloud_config"
        elif key == "externalId":
            suggest = "external_id"
        elif key == "externalRegionId":
            suggest = "external_region_id"
        elif key == "imageId":
            suggest = "image_id"
        elif key == "imageName":
            suggest = "image_name"
        elif key == "osFamily":
            suggest = "os_family"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ProfileImageMapping. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ProfileImageMapping.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ProfileImageMapping.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 name: str,
                 cloud_config: Optional[str] = None,
                 constraints: Optional[Sequence['outputs.ProfileImageMappingConstraint']] = None,
                 description: Optional[str] = None,
                 external_id: Optional[str] = None,
                 external_region_id: Optional[str] = None,
                 image_id: Optional[str] = None,
                 image_name: Optional[str] = None,
                 organization: Optional[str] = None,
                 os_family: Optional[str] = None,
                 owner: Optional[str] = None,
                 private: Optional[bool] = None):
        """
        :param str name: A human-friendly name used as an identifier in APIs that support this option.
        :param str description: A human-friendly description.
        :param str external_region_id: The external regionId of the resource.
        :param str owner: Email of the user that owns the entity.
        """
        pulumi.set(__self__, "name", name)
        if cloud_config is not None:
            pulumi.set(__self__, "cloud_config", cloud_config)
        if constraints is not None:
            pulumi.set(__self__, "constraints", constraints)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if external_id is not None:
            pulumi.set(__self__, "external_id", external_id)
        if external_region_id is not None:
            pulumi.set(__self__, "external_region_id", external_region_id)
        if image_id is not None:
            pulumi.set(__self__, "image_id", image_id)
        if image_name is not None:
            pulumi.set(__self__, "image_name", image_name)
        if organization is not None:
            pulumi.set(__self__, "organization", organization)
        if os_family is not None:
            pulumi.set(__self__, "os_family", os_family)
        if owner is not None:
            pulumi.set(__self__, "owner", owner)
        if private is not None:
            pulumi.set(__self__, "private", private)

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        A human-friendly name used as an identifier in APIs that support this option.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="cloudConfig")
    def cloud_config(self) -> Optional[str]:
        return pulumi.get(self, "cloud_config")

    @property
    @pulumi.getter
    def constraints(self) -> Optional[Sequence['outputs.ProfileImageMappingConstraint']]:
        return pulumi.get(self, "constraints")

    @property
    @pulumi.getter
    def description(self) -> Optional[str]:
        """
        A human-friendly description.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="externalId")
    def external_id(self) -> Optional[str]:
        return pulumi.get(self, "external_id")

    @property
    @pulumi.getter(name="externalRegionId")
    def external_region_id(self) -> Optional[str]:
        """
        The external regionId of the resource.
        """
        return pulumi.get(self, "external_region_id")

    @property
    @pulumi.getter(name="imageId")
    def image_id(self) -> Optional[str]:
        return pulumi.get(self, "image_id")

    @property
    @pulumi.getter(name="imageName")
    def image_name(self) -> Optional[str]:
        return pulumi.get(self, "image_name")

    @property
    @pulumi.getter
    def organization(self) -> Optional[str]:
        return pulumi.get(self, "organization")

    @property
    @pulumi.getter(name="osFamily")
    def os_family(self) -> Optional[str]:
        return pulumi.get(self, "os_family")

    @property
    @pulumi.getter
    def owner(self) -> Optional[str]:
        """
        Email of the user that owns the entity.
        """
        return pulumi.get(self, "owner")

    @property
    @pulumi.getter
    def private(self) -> Optional[bool]:
        return pulumi.get(self, "private")


@pulumi.output_type
class ProfileImageMappingConstraint(dict):
    def __init__(__self__, *,
                 expression: str,
                 mandatory: bool):
        pulumi.set(__self__, "expression", expression)
        pulumi.set(__self__, "mandatory", mandatory)

    @property
    @pulumi.getter
    def expression(self) -> str:
        return pulumi.get(self, "expression")

    @property
    @pulumi.getter
    def mandatory(self) -> bool:
        return pulumi.get(self, "mandatory")


@pulumi.output_type
class GetProfileImageMappingResult(dict):
    def __init__(__self__, *,
                 description: str,
                 external_id: str,
                 external_region_id: str,
                 name: str,
                 organization: str,
                 os_family: str,
                 owner: str,
                 private: bool,
                 cloud_config: Optional[str] = None,
                 constraints: Optional[Sequence['outputs.GetProfileImageMappingConstraintResult']] = None,
                 image_id: Optional[str] = None,
                 image_name: Optional[str] = None):
        """
        :param str description: A human-friendly description.
        :param str external_region_id: The external regionId of the resource.
        :param str name: A human-friendly name used as an identifier in APIs that support this option.
        :param str owner: Email of the user that owns the entity.
        """
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "external_id", external_id)
        pulumi.set(__self__, "external_region_id", external_region_id)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "organization", organization)
        pulumi.set(__self__, "os_family", os_family)
        pulumi.set(__self__, "owner", owner)
        pulumi.set(__self__, "private", private)
        if cloud_config is not None:
            pulumi.set(__self__, "cloud_config", cloud_config)
        if constraints is not None:
            pulumi.set(__self__, "constraints", constraints)
        if image_id is not None:
            pulumi.set(__self__, "image_id", image_id)
        if image_name is not None:
            pulumi.set(__self__, "image_name", image_name)

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        A human-friendly description.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="externalId")
    def external_id(self) -> str:
        return pulumi.get(self, "external_id")

    @property
    @pulumi.getter(name="externalRegionId")
    def external_region_id(self) -> str:
        """
        The external regionId of the resource.
        """
        return pulumi.get(self, "external_region_id")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        A human-friendly name used as an identifier in APIs that support this option.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def organization(self) -> str:
        return pulumi.get(self, "organization")

    @property
    @pulumi.getter(name="osFamily")
    def os_family(self) -> str:
        return pulumi.get(self, "os_family")

    @property
    @pulumi.getter
    def owner(self) -> str:
        """
        Email of the user that owns the entity.
        """
        return pulumi.get(self, "owner")

    @property
    @pulumi.getter
    def private(self) -> bool:
        return pulumi.get(self, "private")

    @property
    @pulumi.getter(name="cloudConfig")
    def cloud_config(self) -> Optional[str]:
        return pulumi.get(self, "cloud_config")

    @property
    @pulumi.getter
    def constraints(self) -> Optional[Sequence['outputs.GetProfileImageMappingConstraintResult']]:
        return pulumi.get(self, "constraints")

    @property
    @pulumi.getter(name="imageId")
    def image_id(self) -> Optional[str]:
        return pulumi.get(self, "image_id")

    @property
    @pulumi.getter(name="imageName")
    def image_name(self) -> Optional[str]:
        return pulumi.get(self, "image_name")


@pulumi.output_type
class GetProfileImageMappingConstraintResult(dict):
    def __init__(__self__, *,
                 expression: str,
                 mandatory: bool):
        pulumi.set(__self__, "expression", expression)
        pulumi.set(__self__, "mandatory", mandatory)

    @property
    @pulumi.getter
    def expression(self) -> str:
        return pulumi.get(self, "expression")

    @property
    @pulumi.getter
    def mandatory(self) -> bool:
        return pulumi.get(self, "mandatory")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'GetSourceBlueprintResult',
    'AwaitableGetSourceBlueprintResult',
    'get_source_blueprint',
    'get_source_blueprint_output',
]

@pulumi.output_type
class GetSourceBlueprintResult:
    """
    A collection of values returned by getSourceBlueprint.
    """
    def __init__(__self__, config=None, created_at=None, created_by=None, description=None, global_=None, id=None, items_found=None, items_imported=None, last_import_completed_at=None, last_import_errors=None, last_import_started_at=None, last_updated_by=None, name=None, project_id=None, type_id=None):
        if config and not isinstance(config, dict):
            raise TypeError("Expected argument 'config' to be a dict")
        pulumi.set(__self__, "config", config)
        if created_at and not isinstance(created_at, str):
            raise TypeError("Expected argument 'created_at' to be a str")
        pulumi.set(__self__, "created_at", created_at)
        if created_by and not isinstance(created_by, str):
            raise TypeError("Expected argument 'created_by' to be a str")
        pulumi.set(__self__, "created_by", created_by)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if global_ and not isinstance(global_, bool):
            raise TypeError("Expected argument 'global_' to be a bool")
        pulumi.set(__self__, "global_", global_)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if items_found and not isinstance(items_found, str):
            raise TypeError("Expected argument 'items_found' to be a str")
        pulumi.set(__self__, "items_found", items_found)
        if items_imported and not isinstance(items_imported, str):
            raise TypeError("Expected argument 'items_imported' to be a str")
        pulumi.set(__self__, "items_imported", items_imported)
        if last_import_completed_at and not isinstance(last_import_completed_at, str):
            raise TypeError("Expected argument 'last_import_completed_at' to be a str")
        pulumi.set(__self__, "last_import_completed_at", last_import_completed_at)
        if last_import_errors and not isinstance(last_import_errors, list):
            raise TypeError("Expected argument 'last_import_errors' to be a list")
        pulumi.set(__self__, "last_import_errors", last_import_errors)
        if last_import_started_at and not isinstance(last_import_started_at, str):
            raise TypeError("Expected argument 'last_import_started_at' to be a str")
        pulumi.set(__self__, "last_import_started_at", last_import_started_at)
        if last_updated_by and not isinstance(last_updated_by, str):
            raise TypeError("Expected argument 'last_updated_by' to be a str")
        pulumi.set(__self__, "last_updated_by", last_updated_by)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)
        if type_id and not isinstance(type_id, str):
            raise TypeError("Expected argument 'type_id' to be a str")
        pulumi.set(__self__, "type_id", type_id)

    @property
    @pulumi.getter
    def config(self) -> Mapping[str, str]:
        """
        Custom configuration of the catalog source as a map of key values.
        """
        return pulumi.get(self, "config")

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> str:
        """
        Date when the entity was created. The date is in ISO 6801 and UTC.
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter(name="createdBy")
    def created_by(self) -> str:
        """
        The user the entity was created by.
        """
        return pulumi.get(self, "created_by")

    @property
    @pulumi.getter
    def description(self) -> Optional[str]:
        """
        Catalog source description.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="global")
    def global_(self) -> bool:
        """
        A flag indicating that all the items can be requested across all projects.
        """
        return pulumi.get(self, "global_")

    @property
    @pulumi.getter
    def id(self) -> Optional[str]:
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="itemsFound")
    def items_found(self) -> str:
        """
        Number of items found in the catalog source.
        """
        return pulumi.get(self, "items_found")

    @property
    @pulumi.getter(name="itemsImported")
    def items_imported(self) -> str:
        """
        Number of items imported from the catalog source.
        """
        return pulumi.get(self, "items_imported")

    @property
    @pulumi.getter(name="lastImportCompletedAt")
    def last_import_completed_at(self) -> str:
        """
        Time at which the last import was completed at.
        """
        return pulumi.get(self, "last_import_completed_at")

    @property
    @pulumi.getter(name="lastImportErrors")
    def last_import_errors(self) -> Sequence[str]:
        """
        A list of errors seen at last time the catalog source is imported.
        """
        return pulumi.get(self, "last_import_errors")

    @property
    @pulumi.getter(name="lastImportStartedAt")
    def last_import_started_at(self) -> str:
        """
        Time at which the last import was started at.
        """
        return pulumi.get(self, "last_import_started_at")

    @property
    @pulumi.getter(name="lastUpdatedBy")
    def last_updated_by(self) -> str:
        """
        The user that last updated the catalog source.
        """
        return pulumi.get(self, "last_updated_by")

    @property
    @pulumi.getter
    def name(self) -> str:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="projectId")
    def project_id(self) -> str:
        return pulumi.get(self, "project_id")

    @property
    @pulumi.getter(name="typeId")
    def type_id(self) -> str:
        """
        Type of catalog source. Example: `blueprint`, `CFT`, etc.
        """
        return pulumi.get(self, "type_id")


class AwaitableGetSourceBlueprintResult(GetSourceBlueprintResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetSourceBlueprintResult(
            config=self.config,
            created_at=self.created_at,
            created_by=self.created_by,
            description=self.description,
            global_=self.global_,
            id=self.id,
            items_found=self.items_found,
            items_imported=self.items_imported,
            last_import_completed_at=self.last_import_completed_at,
            last_import_errors=self.last_import_errors,
            last_import_started_at=self.last_import_started_at,
            last_updated_by=self.last_updated_by,
            name=self.name,
            project_id=self.project_id,
            type_id=self.type_id)


def get_source_blueprint(config: Optional[Mapping[str, str]] = None,
                         description: Optional[str] = None,
                         id: Optional[str] = None,
                         name: Optional[str] = None,
                         project_id: Optional[str] = None,
                         opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetSourceBlueprintResult:
    """
    This data source provides information about a catalog source of type cloud template (blueprint) in vRA.

    ## Example Usage
    ### S

    This is an example of how to get a vRA cloud template catalog source by its name.

    ```python
    import pulumi
    import pulumi_vra as vra

    this = vra.catalog.get_source_blueprint(name=var["catalog_source_name"])
    ```

    This is an example of how to get a vRA cloud template catalog source by its id.

    ```python
    import pulumi
    import pulumi_vra as vra

    this = vra.catalog.get_source_blueprint(id=var["catalog_source_id"])
    ```

    This is an example of how to get a vRA cloud template catalog source by the project id it is associated with.

    ```python
    import pulumi
    import pulumi_vra as vra

    this = vra.catalog.get_source_blueprint(project_id=var["project_id"])
    ```


    :param Mapping[str, str] config: Custom configuration of the catalog source as a map of key values.
    :param str description: Catalog source description.
    :param str id: The id of catalog source. One of `id`, `name` or `project_id`  must be provided.
    :param str name: Name of the catalog source. One of `id`, `name` or `project_id` must be provided.
    :param str project_id: The id of the project.  One of `id`, `name` or `project_id` must be provided.
    """
    __args__ = dict()
    __args__['config'] = config
    __args__['description'] = description
    __args__['id'] = id
    __args__['name'] = name
    __args__['projectId'] = project_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('vra:catalog/getSourceBlueprint:getSourceBlueprint', __args__, opts=opts, typ=GetSourceBlueprintResult).value

    return AwaitableGetSourceBlueprintResult(
        config=__ret__.config,
        created_at=__ret__.created_at,
        created_by=__ret__.created_by,
        description=__ret__.description,
        global_=__ret__.global_,
        id=__ret__.id,
        items_found=__ret__.items_found,
        items_imported=__ret__.items_imported,
        last_import_completed_at=__ret__.last_import_completed_at,
        last_import_errors=__ret__.last_import_errors,
        last_import_started_at=__ret__.last_import_started_at,
        last_updated_by=__ret__.last_updated_by,
        name=__ret__.name,
        project_id=__ret__.project_id,
        type_id=__ret__.type_id)


@_utilities.lift_output_func(get_source_blueprint)
def get_source_blueprint_output(config: Optional[pulumi.Input[Optional[Mapping[str, str]]]] = None,
                                description: Optional[pulumi.Input[Optional[str]]] = None,
                                id: Optional[pulumi.Input[Optional[str]]] = None,
                                name: Optional[pulumi.Input[Optional[str]]] = None,
                                project_id: Optional[pulumi.Input[Optional[str]]] = None,
                                opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetSourceBlueprintResult]:
    """
    This data source provides information about a catalog source of type cloud template (blueprint) in vRA.

    ## Example Usage
    ### S

    This is an example of how to get a vRA cloud template catalog source by its name.

    ```python
    import pulumi
    import pulumi_vra as vra

    this = vra.catalog.get_source_blueprint(name=var["catalog_source_name"])
    ```

    This is an example of how to get a vRA cloud template catalog source by its id.

    ```python
    import pulumi
    import pulumi_vra as vra

    this = vra.catalog.get_source_blueprint(id=var["catalog_source_id"])
    ```

    This is an example of how to get a vRA cloud template catalog source by the project id it is associated with.

    ```python
    import pulumi
    import pulumi_vra as vra

    this = vra.catalog.get_source_blueprint(project_id=var["project_id"])
    ```


    :param Mapping[str, str] config: Custom configuration of the catalog source as a map of key values.
    :param str description: Catalog source description.
    :param str id: The id of catalog source. One of `id`, `name` or `project_id`  must be provided.
    :param str name: Name of the catalog source. One of `id`, `name` or `project_id` must be provided.
    :param str project_id: The id of the project.  One of `id`, `name` or `project_id` must be provided.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['VmcArgs', 'Vmc']

@pulumi.input_type
class VmcArgs:
    def __init__(__self__, *,
                 api_token: pulumi.Input[str],
                 nsx_hostname: pulumi.Input[str],
                 regions: pulumi.Input[Sequence[pulumi.Input[str]]],
                 sddc_name: pulumi.Input[str],
                 vcenter_hostname: pulumi.Input[str],
                 vcenter_password: pulumi.Input[str],
                 vcenter_username: pulumi.Input[str],
                 accept_self_signed_cert: Optional[pulumi.Input[bool]] = None,
                 dc_id: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['VmcTagArgs']]]] = None):
        """
        The set of arguments for constructing a Vmc resource.
        :param pulumi.Input[str] api_token: VMC API access key.
        :param pulumi.Input[str] nsx_hostname: IP address of the NSX Manager server in the specified SDDC / FQDN.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] regions: Set of region names enabled for the cloud account.
        :param pulumi.Input[str] sddc_name: Identifier of the on-premise SDDC to be used by the cloud account. Note that NSX-V SDDCs are not supported.
        :param pulumi.Input[str] vcenter_hostname: IP address or FQDN of the vCenter Server in the specified SDDC. The cloud proxy belongs on this vCenter.
        :param pulumi.Input[str] vcenter_password: Password used to authenticate to the cloud Account.
        :param pulumi.Input[str] vcenter_username: vCenter user name for the specified SDDC. The user requires CloudAdmin credentials. The user does not require CloudGlobalAdmin credentials.
        :param pulumi.Input[bool] accept_self_signed_cert: Accept self-signed certificate when connecting to the cloud account.
        :param pulumi.Input[str] dc_id: Identifier of a data collector VM deployed in the on premise infrastructure. Refer to the data-collector API to create or list data collector.
        :param pulumi.Input[str] description: Human-friendly description.
        :param pulumi.Input[str] name: Human-friendly name used as an identifier in APIs that support this option.
        :param pulumi.Input[Sequence[pulumi.Input['VmcTagArgs']]] tags: Set of tag keys and values to apply to the cloud account.  
               Example:[ { "key" : "vmware", "value": "provider" } ]
        """
        pulumi.set(__self__, "api_token", api_token)
        pulumi.set(__self__, "nsx_hostname", nsx_hostname)
        pulumi.set(__self__, "regions", regions)
        pulumi.set(__self__, "sddc_name", sddc_name)
        pulumi.set(__self__, "vcenter_hostname", vcenter_hostname)
        pulumi.set(__self__, "vcenter_password", vcenter_password)
        pulumi.set(__self__, "vcenter_username", vcenter_username)
        if accept_self_signed_cert is not None:
            pulumi.set(__self__, "accept_self_signed_cert", accept_self_signed_cert)
        if dc_id is not None:
            pulumi.set(__self__, "dc_id", dc_id)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter(name="apiToken")
    def api_token(self) -> pulumi.Input[str]:
        """
        VMC API access key.
        """
        return pulumi.get(self, "api_token")

    @api_token.setter
    def api_token(self, value: pulumi.Input[str]):
        pulumi.set(self, "api_token", value)

    @property
    @pulumi.getter(name="nsxHostname")
    def nsx_hostname(self) -> pulumi.Input[str]:
        """
        IP address of the NSX Manager server in the specified SDDC / FQDN.
        """
        return pulumi.get(self, "nsx_hostname")

    @nsx_hostname.setter
    def nsx_hostname(self, value: pulumi.Input[str]):
        pulumi.set(self, "nsx_hostname", value)

    @property
    @pulumi.getter
    def regions(self) -> pulumi.Input[Sequence[pulumi.Input[str]]]:
        """
        Set of region names enabled for the cloud account.
        """
        return pulumi.get(self, "regions")

    @regions.setter
    def regions(self, value: pulumi.Input[Sequence[pulumi.Input[str]]]):
        pulumi.set(self, "regions", value)

    @property
    @pulumi.getter(name="sddcName")
    def sddc_name(self) -> pulumi.Input[str]:
        """
        Identifier of the on-premise SDDC to be used by the cloud account. Note that NSX-V SDDCs are not supported.
        """
        return pulumi.get(self, "sddc_name")

    @sddc_name.setter
    def sddc_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "sddc_name", value)

    @property
    @pulumi.getter(name="vcenterHostname")
    def vcenter_hostname(self) -> pulumi.Input[str]:
        """
        IP address or FQDN of the vCenter Server in the specified SDDC. The cloud proxy belongs on this vCenter.
        """
        return pulumi.get(self, "vcenter_hostname")

    @vcenter_hostname.setter
    def vcenter_hostname(self, value: pulumi.Input[str]):
        pulumi.set(self, "vcenter_hostname", value)

    @property
    @pulumi.getter(name="vcenterPassword")
    def vcenter_password(self) -> pulumi.Input[str]:
        """
        Password used to authenticate to the cloud Account.
        """
        return pulumi.get(self, "vcenter_password")

    @vcenter_password.setter
    def vcenter_password(self, value: pulumi.Input[str]):
        pulumi.set(self, "vcenter_password", value)

    @property
    @pulumi.getter(name="vcenterUsername")
    def vcenter_username(self) -> pulumi.Input[str]:
        """
        vCenter user name for the specified SDDC. The user requires CloudAdmin credentials. The user does not require CloudGlobalAdmin credentials.
        """
        return pulumi.get(self, "vcenter_username")

    @vcenter_username.setter
    def vcenter_username(self, value: pulumi.Input[str]):
        pulumi.set(self, "vcenter_username", value)

    @property
    @pulumi.getter(name="acceptSelfSignedCert")
    def accept_self_signed_cert(self) -> Optional[pulumi.Input[bool]]:
        """
        Accept self-signed certificate when connecting to the cloud account.
        """
        return pulumi.get(self, "accept_self_signed_cert")

    @accept_self_signed_cert.setter
    def accept_self_signed_cert(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "accept_self_signed_cert", value)

    @property
    @pulumi.getter(name="dcId")
    def dc_id(self) -> Optional[pulumi.Input[str]]:
        """
        Identifier of a data collector VM deployed in the on premise infrastructure. Refer to the data-collector API to create or list data collector.
        """
        return pulumi.get(self, "dc_id")

    @dc_id.setter
    def dc_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "dc_id", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Human-friendly description.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Human-friendly name used as an identifier in APIs that support this option.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['VmcTagArgs']]]]:
        """
        Set of tag keys and values to apply to the cloud account.  
        Example:[ { "key" : "vmware", "value": "provider" } ]
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['VmcTagArgs']]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _VmcState:
    def __init__(__self__, *,
                 accept_self_signed_cert: Optional[pulumi.Input[bool]] = None,
                 api_token: Optional[pulumi.Input[str]] = None,
                 created_at: Optional[pulumi.Input[str]] = None,
                 dc_id: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 links: Optional[pulumi.Input[Sequence[pulumi.Input['VmcLinkArgs']]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 nsx_hostname: Optional[pulumi.Input[str]] = None,
                 org_id: Optional[pulumi.Input[str]] = None,
                 owner: Optional[pulumi.Input[str]] = None,
                 regions: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 sddc_name: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['VmcTagArgs']]]] = None,
                 updated_at: Optional[pulumi.Input[str]] = None,
                 vcenter_hostname: Optional[pulumi.Input[str]] = None,
                 vcenter_password: Optional[pulumi.Input[str]] = None,
                 vcenter_username: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering Vmc resources.
        :param pulumi.Input[bool] accept_self_signed_cert: Accept self-signed certificate when connecting to the cloud account.
        :param pulumi.Input[str] api_token: VMC API access key.
        :param pulumi.Input[str] created_at: Date when entity was created. Date and time format is ISO 8601 and UTC.
        :param pulumi.Input[str] dc_id: Identifier of a data collector VM deployed in the on premise infrastructure. Refer to the data-collector API to create or list data collector.
        :param pulumi.Input[str] description: Human-friendly description.
        :param pulumi.Input[Sequence[pulumi.Input['VmcLinkArgs']]] links: HATEOAS of entity.
        :param pulumi.Input[str] name: Human-friendly name used as an identifier in APIs that support this option.
        :param pulumi.Input[str] nsx_hostname: IP address of the NSX Manager server in the specified SDDC / FQDN.
        :param pulumi.Input[str] org_id: ID of organization that entity belongs to.
        :param pulumi.Input[str] owner: Email of entity owner.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] regions: Set of region names enabled for the cloud account.
        :param pulumi.Input[str] sddc_name: Identifier of the on-premise SDDC to be used by the cloud account. Note that NSX-V SDDCs are not supported.
        :param pulumi.Input[Sequence[pulumi.Input['VmcTagArgs']]] tags: Set of tag keys and values to apply to the cloud account.  
               Example:[ { "key" : "vmware", "value": "provider" } ]
        :param pulumi.Input[str] updated_at: Date when the entity was last updated. Date and time format is ISO 8601 and UTC.
        :param pulumi.Input[str] vcenter_hostname: IP address or FQDN of the vCenter Server in the specified SDDC. The cloud proxy belongs on this vCenter.
        :param pulumi.Input[str] vcenter_password: Password used to authenticate to the cloud Account.
        :param pulumi.Input[str] vcenter_username: vCenter user name for the specified SDDC. The user requires CloudAdmin credentials. The user does not require CloudGlobalAdmin credentials.
        """
        if accept_self_signed_cert is not None:
            pulumi.set(__self__, "accept_self_signed_cert", accept_self_signed_cert)
        if api_token is not None:
            pulumi.set(__self__, "api_token", api_token)
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if dc_id is not None:
            pulumi.set(__self__, "dc_id", dc_id)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if links is not None:
            pulumi.set(__self__, "links", links)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if nsx_hostname is not None:
            pulumi.set(__self__, "nsx_hostname", nsx_hostname)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if owner is not None:
            pulumi.set(__self__, "owner", owner)
        if regions is not None:
            pulumi.set(__self__, "regions", regions)
        if sddc_name is not None:
            pulumi.set(__self__, "sddc_name", sddc_name)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if updated_at is not None:
            pulumi.set(__self__, "updated_at", updated_at)
        if vcenter_hostname is not None:
            pulumi.set(__self__, "vcenter_hostname", vcenter_hostname)
        if vcenter_password is not None:
            pulumi.set(__self__, "vcenter_password", vcenter_password)
        if vcenter_username is not None:
            pulumi.set(__self__, "vcenter_username", vcenter_username)

    @property
    @pulumi.getter(name="acceptSelfSignedCert")
    def accept_self_signed_cert(self) -> Optional[pulumi.Input[bool]]:
        """
        Accept self-signed certificate when connecting to the cloud account.
        """
        return pulumi.get(self, "accept_self_signed_cert")

    @accept_self_signed_cert.setter
    def accept_self_signed_cert(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "accept_self_signed_cert", value)

    @property
    @pulumi.getter(name="apiToken")
    def api_token(self) -> Optional[pulumi.Input[str]]:
        """
        VMC API access key.
        """
        return pulumi.get(self, "api_token")

    @api_token.setter
    def api_token(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "api_token", value)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[str]]:
        """
        Date when entity was created. Date and time format is ISO 8601 and UTC.
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "created_at", value)

    @property
    @pulumi.getter(name="dcId")
    def dc_id(self) -> Optional[pulumi.Input[str]]:
        """
        Identifier of a data collector VM deployed in the on premise infrastructure. Refer to the data-collector API to create or list data collector.
        """
        return pulumi.get(self, "dc_id")

    @dc_id.setter
    def dc_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "dc_id", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Human-friendly description.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def links(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['VmcLinkArgs']]]]:
        """
        HATEOAS of entity.
        """
        return pulumi.get(self, "links")

    @links.setter
    def links(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['VmcLinkArgs']]]]):
        pulumi.set(self, "links", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Human-friendly name used as an identifier in APIs that support this option.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="nsxHostname")
    def nsx_hostname(self) -> Optional[pulumi.Input[str]]:
        """
        IP address of the NSX Manager server in the specified SDDC / FQDN.
        """
        return pulumi.get(self, "nsx_hostname")

    @nsx_hostname.setter
    def nsx_hostname(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "nsx_hostname", value)

    @property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[str]]:
        """
        ID of organization that entity belongs to.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "org_id", value)

    @property
    @pulumi.getter
    def owner(self) -> Optional[pulumi.Input[str]]:
        """
        Email of entity owner.
        """
        return pulumi.get(self, "owner")

    @owner.setter
    def owner(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "owner", value)

    @property
    @pulumi.getter
    def regions(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        Set of region names enabled for the cloud account.
        """
        return pulumi.get(self, "regions")

    @regions.setter
    def regions(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "regions", value)

    @property
    @pulumi.getter(name="sddcName")
    def sddc_name(self) -> Optional[pulumi.Input[str]]:
        """
        Identifier of the on-premise SDDC to be used by the cloud account. Note that NSX-V SDDCs are not supported.
        """
        return pulumi.get(self, "sddc_name")

    @sddc_name.setter
    def sddc_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "sddc_name", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['VmcTagArgs']]]]:
        """
        Set of tag keys and values to apply to the cloud account.  
        Example:[ { "key" : "vmware", "value": "provider" } ]
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['VmcTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> Optional[pulumi.Input[str]]:
        """
        Date when the entity was last updated. Date and time format is ISO 8601 and UTC.
        """
        return pulumi.get(self, "updated_at")

    @updated_at.setter
    def updated_at(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "updated_at", value)

    @property
    @pulumi.getter(name="vcenterHostname")
    def vcenter_hostname(self) -> Optional[pulumi.Input[str]]:
        """
        IP address or FQDN of the vCenter Server in the specified SDDC. The cloud proxy belongs on this vCenter.
        """
        return pulumi.get(self, "vcenter_hostname")

    @vcenter_hostname.setter
    def vcenter_hostname(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "vcenter_hostname", value)

    @property
    @pulumi.getter(name="vcenterPassword")
    def vcenter_password(self) -> Optional[pulumi.Input[str]]:
        """
        Password used to authenticate to the cloud Account.
        """
        return pulumi.get(self, "vcenter_password")

    @vcenter_password.setter
    def vcenter_password(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "vcenter_password", value)

    @property
    @pulumi.getter(name="vcenterUsername")
    def vcenter_username(self) -> Optional[pulumi.Input[str]]:
        """
        vCenter user name for the specified SDDC. The user requires CloudAdmin credentials. The user does not require CloudGlobalAdmin credentials.
        """
        return pulumi.get(self, "vcenter_username")

    @vcenter_username.setter
    def vcenter_username(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "vcenter_username", value)


class Vmc(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 accept_self_signed_cert: Optional[pulumi.Input[bool]] = None,
                 api_token: Optional[pulumi.Input[str]] = None,
                 dc_id: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 nsx_hostname: Optional[pulumi.Input[str]] = None,
                 regions: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 sddc_name: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['VmcTagArgs']]]]] = None,
                 vcenter_hostname: Optional[pulumi.Input[str]] = None,
                 vcenter_password: Optional[pulumi.Input[str]] = None,
                 vcenter_username: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Creates a VMware vRealize Automation VMC cloud account resource.

        ## Example Usage
        ### S

        **Create VMC cloud account:**

        The following example shows how to create a VMC cloud account resource.

        ```python
        import pulumi
        import pulumiverse_vra as vra

        this = vra.cloudaccount.Vmc("this",
            description="tf test vmc cloud account",
            api_token=var["api_token"],
            sddc_name=var["sddc_name"],
            vcenter_hostname=var["vcenter_hostname"],
            vcenter_password=var["vcenter_password"],
            vcenter_username=var["vcenter_username"],
            nsx_hostname=var["nsx_hostname"],
            dc_id=var["data_collector_id"],
            regions=var["regions"],
            accept_self_signed_cert=True,
            tags=[vra.cloudaccount.VmcTagArgs(
                key="foo",
                value="bar",
            )])
        ```

        ## Import

        To import the VMC cloud account, use the ID as in the following example

        ```sh
         $ pulumi import vra:cloudaccount/vmc:Vmc new_vmc 05956583-6488-4e7d-84c9-92a7b7219a15`
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] accept_self_signed_cert: Accept self-signed certificate when connecting to the cloud account.
        :param pulumi.Input[str] api_token: VMC API access key.
        :param pulumi.Input[str] dc_id: Identifier of a data collector VM deployed in the on premise infrastructure. Refer to the data-collector API to create or list data collector.
        :param pulumi.Input[str] description: Human-friendly description.
        :param pulumi.Input[str] name: Human-friendly name used as an identifier in APIs that support this option.
        :param pulumi.Input[str] nsx_hostname: IP address of the NSX Manager server in the specified SDDC / FQDN.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] regions: Set of region names enabled for the cloud account.
        :param pulumi.Input[str] sddc_name: Identifier of the on-premise SDDC to be used by the cloud account. Note that NSX-V SDDCs are not supported.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['VmcTagArgs']]]] tags: Set of tag keys and values to apply to the cloud account.  
               Example:[ { "key" : "vmware", "value": "provider" } ]
        :param pulumi.Input[str] vcenter_hostname: IP address or FQDN of the vCenter Server in the specified SDDC. The cloud proxy belongs on this vCenter.
        :param pulumi.Input[str] vcenter_password: Password used to authenticate to the cloud Account.
        :param pulumi.Input[str] vcenter_username: vCenter user name for the specified SDDC. The user requires CloudAdmin credentials. The user does not require CloudGlobalAdmin credentials.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: VmcArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Creates a VMware vRealize Automation VMC cloud account resource.

        ## Example Usage
        ### S

        **Create VMC cloud account:**

        The following example shows how to create a VMC cloud account resource.

        ```python
        import pulumi
        import pulumiverse_vra as vra

        this = vra.cloudaccount.Vmc("this",
            description="tf test vmc cloud account",
            api_token=var["api_token"],
            sddc_name=var["sddc_name"],
            vcenter_hostname=var["vcenter_hostname"],
            vcenter_password=var["vcenter_password"],
            vcenter_username=var["vcenter_username"],
            nsx_hostname=var["nsx_hostname"],
            dc_id=var["data_collector_id"],
            regions=var["regions"],
            accept_self_signed_cert=True,
            tags=[vra.cloudaccount.VmcTagArgs(
                key="foo",
                value="bar",
            )])
        ```

        ## Import

        To import the VMC cloud account, use the ID as in the following example

        ```sh
         $ pulumi import vra:cloudaccount/vmc:Vmc new_vmc 05956583-6488-4e7d-84c9-92a7b7219a15`
        ```

        :param str resource_name: The name of the resource.
        :param VmcArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(VmcArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 accept_self_signed_cert: Optional[pulumi.Input[bool]] = None,
                 api_token: Optional[pulumi.Input[str]] = None,
                 dc_id: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 nsx_hostname: Optional[pulumi.Input[str]] = None,
                 regions: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 sddc_name: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['VmcTagArgs']]]]] = None,
                 vcenter_hostname: Optional[pulumi.Input[str]] = None,
                 vcenter_password: Optional[pulumi.Input[str]] = None,
                 vcenter_username: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = VmcArgs.__new__(VmcArgs)

            __props__.__dict__["accept_self_signed_cert"] = accept_self_signed_cert
            if api_token is None and not opts.urn:
                raise TypeError("Missing required property 'api_token'")
            __props__.__dict__["api_token"] = api_token
            __props__.__dict__["dc_id"] = dc_id
            __props__.__dict__["description"] = description
            __props__.__dict__["name"] = name
            if nsx_hostname is None and not opts.urn:
                raise TypeError("Missing required property 'nsx_hostname'")
            __props__.__dict__["nsx_hostname"] = nsx_hostname
            if regions is None and not opts.urn:
                raise TypeError("Missing required property 'regions'")
            __props__.__dict__["regions"] = regions
            if sddc_name is None and not opts.urn:
                raise TypeError("Missing required property 'sddc_name'")
            __props__.__dict__["sddc_name"] = sddc_name
            __props__.__dict__["tags"] = tags
            if vcenter_hostname is None and not opts.urn:
                raise TypeError("Missing required property 'vcenter_hostname'")
            __props__.__dict__["vcenter_hostname"] = vcenter_hostname
            if vcenter_password is None and not opts.urn:
                raise TypeError("Missing required property 'vcenter_password'")
            __props__.__dict__["vcenter_password"] = vcenter_password
            if vcenter_username is None and not opts.urn:
                raise TypeError("Missing required property 'vcenter_username'")
            __props__.__dict__["vcenter_username"] = vcenter_username
            __props__.__dict__["created_at"] = None
            __props__.__dict__["links"] = None
            __props__.__dict__["org_id"] = None
            __props__.__dict__["owner"] = None
            __props__.__dict__["updated_at"] = None
        super(Vmc, __self__).__init__(
            'vra:cloudaccount/vmc:Vmc',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            accept_self_signed_cert: Optional[pulumi.Input[bool]] = None,
            api_token: Optional[pulumi.Input[str]] = None,
            created_at: Optional[pulumi.Input[str]] = None,
            dc_id: Optional[pulumi.Input[str]] = None,
            description: Optional[pulumi.Input[str]] = None,
            links: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['VmcLinkArgs']]]]] = None,
            name: Optional[pulumi.Input[str]] = None,
            nsx_hostname: Optional[pulumi.Input[str]] = None,
            org_id: Optional[pulumi.Input[str]] = None,
            owner: Optional[pulumi.Input[str]] = None,
            regions: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            sddc_name: Optional[pulumi.Input[str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['VmcTagArgs']]]]] = None,
            updated_at: Optional[pulumi.Input[str]] = None,
            vcenter_hostname: Optional[pulumi.Input[str]] = None,
            vcenter_password: Optional[pulumi.Input[str]] = None,
            vcenter_username: Optional[pulumi.Input[str]] = None) -> 'Vmc':
        """
        Get an existing Vmc resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] accept_self_signed_cert: Accept self-signed certificate when connecting to the cloud account.
        :param pulumi.Input[str] api_token: VMC API access key.
        :param pulumi.Input[str] created_at: Date when entity was created. Date and time format is ISO 8601 and UTC.
        :param pulumi.Input[str] dc_id: Identifier of a data collector VM deployed in the on premise infrastructure. Refer to the data-collector API to create or list data collector.
        :param pulumi.Input[str] description: Human-friendly description.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['VmcLinkArgs']]]] links: HATEOAS of entity.
        :param pulumi.Input[str] name: Human-friendly name used as an identifier in APIs that support this option.
        :param pulumi.Input[str] nsx_hostname: IP address of the NSX Manager server in the specified SDDC / FQDN.
        :param pulumi.Input[str] org_id: ID of organization that entity belongs to.
        :param pulumi.Input[str] owner: Email of entity owner.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] regions: Set of region names enabled for the cloud account.
        :param pulumi.Input[str] sddc_name: Identifier of the on-premise SDDC to be used by the cloud account. Note that NSX-V SDDCs are not supported.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['VmcTagArgs']]]] tags: Set of tag keys and values to apply to the cloud account.  
               Example:[ { "key" : "vmware", "value": "provider" } ]
        :param pulumi.Input[str] updated_at: Date when the entity was last updated. Date and time format is ISO 8601 and UTC.
        :param pulumi.Input[str] vcenter_hostname: IP address or FQDN of the vCenter Server in the specified SDDC. The cloud proxy belongs on this vCenter.
        :param pulumi.Input[str] vcenter_password: Password used to authenticate to the cloud Account.
        :param pulumi.Input[str] vcenter_username: vCenter user name for the specified SDDC. The user requires CloudAdmin credentials. The user does not require CloudGlobalAdmin credentials.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _VmcState.__new__(_VmcState)

        __props__.__dict__["accept_self_signed_cert"] = accept_self_signed_cert
        __props__.__dict__["api_token"] = api_token
        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["dc_id"] = dc_id
        __props__.__dict__["description"] = description
        __props__.__dict__["links"] = links
        __props__.__dict__["name"] = name
        __props__.__dict__["nsx_hostname"] = nsx_hostname
        __props__.__dict__["org_id"] = org_id
        __props__.__dict__["owner"] = owner
        __props__.__dict__["regions"] = regions
        __props__.__dict__["sddc_name"] = sddc_name
        __props__.__dict__["tags"] = tags
        __props__.__dict__["updated_at"] = updated_at
        __props__.__dict__["vcenter_hostname"] = vcenter_hostname
        __props__.__dict__["vcenter_password"] = vcenter_password
        __props__.__dict__["vcenter_username"] = vcenter_username
        return Vmc(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="acceptSelfSignedCert")
    def accept_self_signed_cert(self) -> pulumi.Output[Optional[bool]]:
        """
        Accept self-signed certificate when connecting to the cloud account.
        """
        return pulumi.get(self, "accept_self_signed_cert")

    @property
    @pulumi.getter(name="apiToken")
    def api_token(self) -> pulumi.Output[str]:
        """
        VMC API access key.
        """
        return pulumi.get(self, "api_token")

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[str]:
        """
        Date when entity was created. Date and time format is ISO 8601 and UTC.
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter(name="dcId")
    def dc_id(self) -> pulumi.Output[Optional[str]]:
        """
        Identifier of a data collector VM deployed in the on premise infrastructure. Refer to the data-collector API to create or list data collector.
        """
        return pulumi.get(self, "dc_id")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[str]]:
        """
        Human-friendly description.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def links(self) -> pulumi.Output[Sequence['outputs.VmcLink']]:
        """
        HATEOAS of entity.
        """
        return pulumi.get(self, "links")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        Human-friendly name used as an identifier in APIs that support this option.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="nsxHostname")
    def nsx_hostname(self) -> pulumi.Output[str]:
        """
        IP address of the NSX Manager server in the specified SDDC / FQDN.
        """
        return pulumi.get(self, "nsx_hostname")

    @property
    @pulumi.getter(name="orgId")
    def org_id(self) -> pulumi.Output[str]:
        """
        ID of organization that entity belongs to.
        """
        return pulumi.get(self, "org_id")

    @property
    @pulumi.getter
    def owner(self) -> pulumi.Output[str]:
        """
        Email of entity owner.
        """
        return pulumi.get(self, "owner")

    @property
    @pulumi.getter
    def regions(self) -> pulumi.Output[Sequence[str]]:
        """
        Set of region names enabled for the cloud account.
        """
        return pulumi.get(self, "regions")

    @property
    @pulumi.getter(name="sddcName")
    def sddc_name(self) -> pulumi.Output[str]:
        """
        Identifier of the on-premise SDDC to be used by the cloud account. Note that NSX-V SDDCs are not supported.
        """
        return pulumi.get(self, "sddc_name")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Sequence['outputs.VmcTag']]:
        """
        Set of tag keys and values to apply to the cloud account.  
        Example:[ { "key" : "vmware", "value": "provider" } ]
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> pulumi.Output[str]:
        """
        Date when the entity was last updated. Date and time format is ISO 8601 and UTC.
        """
        return pulumi.get(self, "updated_at")

    @property
    @pulumi.getter(name="vcenterHostname")
    def vcenter_hostname(self) -> pulumi.Output[str]:
        """
        IP address or FQDN of the vCenter Server in the specified SDDC. The cloud proxy belongs on this vCenter.
        """
        return pulumi.get(self, "vcenter_hostname")

    @property
    @pulumi.getter(name="vcenterPassword")
    def vcenter_password(self) -> pulumi.Output[str]:
        """
        Password used to authenticate to the cloud Account.
        """
        return pulumi.get(self, "vcenter_password")

    @property
    @pulumi.getter(name="vcenterUsername")
    def vcenter_username(self) -> pulumi.Output[str]:
        """
        vCenter user name for the specified SDDC. The user requires CloudAdmin credentials. The user does not require CloudGlobalAdmin credentials.
        """
        return pulumi.get(self, "vcenter_username")

